from setuptools import setup
setup(
    name='teslajsonpy2',
    version='0.1.24',
    packages=['teslajsonpy2'],
    include_package_data=True,
    python_requires='>=3',
    license='WTFPL',
    description='A library to work with Tesla API.',
    long_description='A library to work with Tesla car API.',
    url='https://github.com/rudical/teslajsonpy2',
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Internet',
    ],
)
